==> aroundme_0_5_0.tar.tgz: aroundme_0_5_0/aroundme/template/barnraiser_01/sn_invite.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="sn_invite.php" method="post">

<table width="100%" cellpadding="0" cellspacing="0" border="0">
	<tr>
		<td width="560" valign="top">
			<div class="box_top">
			
				<?php echo $lang['section_invite'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td width="50%" valign="top">
						
						<table cellpadding="4" cellspacing="0" border="0" width="100%">
							<tr>
								<td colspan="2">
									<b><?php echo $lang['hdr_invite'];?></b><br />
								</td>
							</tr>
							<tr>
								<td colspan="2">
									<?php echo $lang['txt_invite_help'];?><br />
								</td>
							</tr>
							<tr>
								<td colspan="2">
									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />
								</td>
							</tr>
							<tr>
								<td valign="top">
									<label for="id_to"><?php echo $lang['form_emails'];?></label><br />
								</td>
								<td width="10">
									<textarea id="id_to" name="data[to]" rows="6" cols="32"></textarea><br />
								</td>
							</tr>
							<tr>
								<td colspan="2">
									<?php echo $lang['txt_invite_to_help'];?><br />
								</td>
							</tr>
						</table>
					</td>
					<td width="20">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="1" alt="" /><br />
					</td>
					<td width="50%" valign="top">
						<?php
						if (isset($total_emails_sent)) {
						?>
						<table cellpadding="4" cellspacing="0" border="0" width="100%">
							<tr>
								<td>
									<b><?php echo $lang['section_sent'];?></b><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $lang['txt_emails_sent'];?>: <?php echo $total_emails_sent;?><br />
								</td>
							</tr>
						</table>
			
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
						<?php }?>
						
						<table cellpadding="4" cellspacing="0" border="0" width="100%">
							<tr>
								<td colspan="2">
								
									<b><?php echo $lang['hdr_email'];?></b><br />
								</td>
							</tr>
							<tr>
								<td colspan="2">
									<?php echo $lang['txt_email_intro'];?><br />
								</td>
							</tr>
							<tr>
								<td colspan="2">
									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />
								</td>
							</tr>
							<tr>
								<td valign="top">
									<label for="id_subject"><?php echo $lang['form_subject'];?></label><br />
								</td>
								<td valign="top">
									<input id="id_subject" type="text" size="46" name="data[subject]" value="<?php echo $lang['txt_invite'];?>" class="formInput" /><br />
								</td>
							</tr>
							<tr>
								<td valign="top">
									<label for="id_message"><?php echo $lang['form_message'];?></label><br />
								</td>
								<td valign="top">
									<textarea id="id_message" name="data[message]" rows="4" cols="43"><?php echo $lang['txt_invite_message_txt'];?></textarea>
								</td>
							</tr>
							<tr>
								<td valign="top" align="right" colspan="2">
									<input type="submit" name="send_invite" value="<?php echo $lang['sub_invite'];?>" class="button_urgent" /><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
			</table>
			
			
			


			
			</div>
			
			<div id="box_bottom">
			<table cellpadding="0" cellspacing="0" border="0" width="100%">
				<tr>
					<td align="left">
						<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
					</td>
					<td align="left">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
					</td>
					<td align="right">
						<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
					</td>
				</tr>
			</table>
			</div>
		</td>
	</tr>
</table>

==> aroundme_0_6_2.tar.tgz: aroundme_0_6_2/aroundme/template/barnraiser_01/sn_invite.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
?>

<form action="sn_invite.php" method="post">

<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_invite'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<?php
			if (isset($display) && $display == 'invite') {
			?>
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td width="50%" valign="top">
						
						<table cellpadding="4" cellspacing="0" border="0" width="100%">
							<tr>
								<td colspan="2">
									<b><?php echo $lang['hdr_invite'];?></b><br />
								</td>
							</tr>
							<tr>
								<td colspan="2">
									<?php echo $lang['txt_invite_help'];?><br />
								</td>
							</tr>
							<tr>
								<td colspan="2">
									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />
								</td>
							</tr>
							<tr>
								<td valign="top">
									<label for="id_to"><?php echo $lang['form_emails'];?></label><br />
								</td>
								<td width="10">
									<textarea id="id_to" name="to" rows="6" cols="32"></textarea><br />
								</td>
							</tr>
							<tr>
								<td colspan="2">
									<?php echo $lang['txt_invite_to_help'];?><br />
								</td>
							</tr>
						</table>
					</td>
					<td width="20">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="1" alt="" /><br />
					</td>
					<td width="50%" valign="top">
						<?php
						if (isset($total_emails_sent)) {
						?>
						<table cellpadding="4" cellspacing="0" border="0" width="100%">
							<tr>
								<td>
									<b><?php echo $lang['hdr_sent'];?></b><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $lang['txt_emails_sent'];?>: <?php echo $total_emails_sent;?><br />
								</td>
							</tr>
						</table>
			
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
						<?php }?>
						
						<table cellpadding="4" cellspacing="0" border="0" width="100%">
							<tr>
								<td colspan="2">
								
									<b><?php echo $lang['hdr_email'];?></b><br />
								</td>
							</tr>
							<tr>
								<td colspan="2">
									<?php echo $lang['txt_email_intro'];?><br />
								</td>
							</tr>
							<tr>
								<td colspan="2">
									<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />
								</td>
							</tr>
							<tr>
								<td valign="top">
									<label for="id_subject"><?php echo $lang['form_subject'];?></label><br />
								</td>
								<td valign="top">
									<input id="id_subject" type="text" size="46" name="subject" value="<?php echo $lang['txt_invite'];?>" class="formInput" /><br />
								</td>
							</tr>
							<tr>
								<td valign="top">
									<label for="id_message"><?php echo $lang['form_message'];?></label><br />
								</td>
								<td valign="top">
									<textarea id="id_message" name="message" rows="4" cols="43"><?php echo $lang['txt_invite_message_txt'];?></textarea>
								</td>
							</tr>
							<tr>
								<td valign="top" align="right" colspan="2">
									<input type="submit" name="send_invite" value="<?php echo $lang['sub_invite'];?>" class="button_urgent" /><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
			</table>
			<?php
			}
			else {
			?>
			<?php
			if (!isset($me['user_id'])) {
				echo $lang['err_invite_denied_login'];
			}
			else {
				echo $lang['err_invite_denied'];
			}
			?><br />
			<?php }?>
		</div>
	</div>
</div>
		
<div class="box_bottom">
	<span class="box_bottom_right"></span>
	<span class="box_bottom_left"></span>
</div>
</form>
